#!/bin/sh
DT=`date +"%d%m%y-%H%M%S"`
SCRIPT_VERSION='1.2.2-eva2000.16'
SCRIPT_DATE='29/04/2012'
SCRIPT_AUTHOR='BTCentral (btcentral.org.uk)'
SCRIPT_MODIFICATION_AUTHOR='eva2000 (vbtechsupport.com)'
SCRIPT_URL='http://centminmod.com'
COPYRIGHT="Copyright 2011-2012 CentminMod.com, BTCentral"
DISCLAIMER='This software is provided "as is" in the hope that it will be useful, but WITHOUT ANY WARRANTY, to the extent permitted by law; without even the implied warranty of MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.'
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option)
# any later version. See the included license.txt for futher details.
#
# PLEASE MODIFY VALUES BELOW THIS LINE ++++++++++++++++++++++++++++++++++++++
# Note: Please enter y for yes or n for no.

#####################################################
# Pre-Checks to prevent screw ups

if [ ! -f /usr/bin/wget ]; then
echo "wget not found !! "
echo "installing wget"
yum -y -q wget
echo "aborting script... please re-run centmin.sh"
exit
fi

if [ ! -f /usr/bin/tee ]; then
#echo "tee not found !! "
#echo "installing tee"
yum -y -q coreutils
fi

if [ -f /var/cpanel/cpanel.config ]; then
echo "WHM/Cpanel detected.. centmin mod NOT compatible"
echo "aborting script..."
exit
fi

if [ -f /etc/psa/.psa.shadow ]; then
echo "Plesk detected.. centmin mod NOT compatible"
echo "aborting script..."
exit
fi

if [ -f /etc/init.d/directadmin ]; then
echo "DirectAdmin detected.. centmin mod NOT compatible"
echo "aborting script..."
exit
fi

TESTEDCENTOSVER='6.2'
CENTOSVER=`cat /etc/redhat-release | awk '{ print $3 }'`

if [ "$CENTOSVER" == 'release' ]; then
CENTOSVER=`cat /etc/redhat-release | awk '{ print $4 }'`
fi

#####################################################
# Enable or disable menu mode

ENABLE_MENU='y'

source "inc/centminlogs.inc"
source "inc/yuminstall.inc"
source "inc/centoscheck.inc"
source "inc/nginx_backup.inc"
source "inc/nsd_install.inc"
source "inc/nsdsetup.inc"
source "inc/nsd_reinstall.inc"
source "inc/logrotate_nginx.inc"
source "inc/logrotate_phpfpm.inc"
source "inc/nginx_configure.inc"
source "inc/nginx_configure_openresty.inc"
source "inc/php_configure.inc"
source "inc/nginx_modules.inc"
source "inc/nginx_modules_openresty.inc"
source "inc/sshd.inc"
source "inc/openvz_stack.inc"
source "inc/nginx_addvhost.inc"
source "inc/mariadb_upgrade.inc"
source "inc/nginx_errorpage.inc"
source "inc/sendmail.inc"
source "inc/compress.inc"
source "inc/diskalert.inc"
source "inc/phpsededit.inc"
source "inc/csfinstall.inc"
source "inc/csftweaks.inc"
source "inc/xcache_installask.inc"
source "inc/xcache_install.inc"
source "inc/xcache_reinstall.inc"
source "inc/apcprotect.inc"
source "inc/apcinstall.inc"
source "inc/apcreinstall.inc"
source "inc/ffmpeginstall.inc"

checkcentosver

#####################################################

if [ -f /proc/user_beancounters ]; then

CPUS='1'
MAKETHREADS=" -j$CPUS"

else

# speed up make
CPUS=`cat "/proc/cpuinfo" | grep "processor"|wc -l`
MAKETHREADS=" -j$CPUS"

fi

# General Configuration
NGINXUPGRADESLEEP='20'
ZONEINFO=Australia/Brisbane  # Set Timezone
NSD_INSTALL=y                # Install NSD (DNS Server)
NSD_VERSION='3.2.10'          # NSD Version
NTP_INSTALL=y                # Install Network time protocol daemon
NGINX_INSTALL=y           # Install Nginx (Webserver)
NGINX_OPENRESTY=n     # Agentzh's openresty Nginx modules
PHP_INSTALL=y                # Install PHP /w Fast Process Manager

########################################################
# Choice of installing MariaDB 5.2 via RPM or via MariaDB 5.2 CentOS YUM Repo
# If MDB_YUMREPOINSTALL=y and MDB_INSTALL=n then MDB_VERONLY version 
# number won't have any effect in determining version of MariaDB 5.2.x to install. 
# YUM Repo will install whatever is latest MariaDB 5.2.x version available via the YUM REPO

MDB_INSTALL=y                # Install via RPM MariaDB MySQL Server replacement (Not recommended for VPS with less than 512MB RAM!)
MDB_YUMREPOINSTALL=n		  # Install MariaDB 5.2 via CentOS YUM Repo

# Define current MariaDB version
MDB_VERONLY='5.2.12'
MDB_BUILD='115'
MDB_VERSION="${MDB_VERONLY}-${MDB_BUILD}"     # Use this version of MariaDB ${MDB_VERONLY}

# Define previous MariaDB version for proper upgrade
MDB_PREVERONLY='5.2.11'
MDB_PREBUILD='115'
MDB_PREVERSION="${MDB_PREVERONLY}-${MDB_PREBUILD}"     # Use this version of MariaDB ${MDB_VERONLY}
########################################################


# Optionally, if you want to install MariaDB instead of standard MySQL you can do. 
# Set MDB_INSTALL=y and MYSQL_INSTALL=n
MYSQL_INSTALL=n              # Install MySQL Server (MariaDB recommended)
SENDMAIL_INSTALL=y           # Install Sendmail (and mailx)
# Nginx
NGINX_VERSION='1.2.0'        # Use this version of Nginx
NGINXBACKUP='y'
NGINXDIR='/usr/local/nginx'
NGINXCONFDIR="${NGINXDIR}/conf"
NGINXBACKUPDIR='/usr/local/nginxbackup'
OPENSSL_VERSION='1.0.0e'     # Use this version of OpenSSL

# Choose whether to compile Nginx --with-google_perftools_module
GPERFTOOLS_SOURCEINSTALL=n
LIBUNWIND_VERSION='0.99'     # note google perftool specifically requies v0.99 and no other
GPERFTOOLS_VERSION='1.8.3'     # Use this version of google-perftools

# Choose whether to compile PCRE from source. Note PHP 5.3.8 already includes PCRE v8.12
PCRE_SOURCEINSTALL=n     
PCRE_VERSION='8.13'          # Use this version of PCRE library

# PHP and Cache/Acceleration
MEMCACHED_INSTALL=y          # Install Memcached
LIBEVENT_VERSION='2.0.18'    # Use this version of Libevent
MEMCACHED_VERSION='1.4.13'    # Use this version of Memcached
MEMCACHE_VERSION='3.0.5'     # Use this version of Memcache - note issues with 3.0.6

FFMPEGVER='0.6.0'
SUHOSINVER='0.9.33'
PHP_VERSION='5.3.11'          # Use this version of PHP
PHP_MIRRORURL='http://us.php.net'
PHPUPGRADE_MIRRORURL='http://us.php.net'
XCACHE_VERSION='2.0.0'       # Use this version of Xcache
APCCACHE_VERSION='3.1.10'       # Use this version of APC Cache
# Python
PYTHON_VERSION='2.7.2'       # Use this version of Python

# The default is stable, you can change this to development if you wish
#ARCH_OVERRIDE='i386'
# Uncomment the above line if you are running a 32bit Paravirtulized Xen VPS
# on a 64bit host node.

# YOU SHOULD NOT NEED TO MODIFY ANYTHING BELOW THIS LINE  +++++++++++++++++++
# JUST RUN chmod +x ./centmin.sh && ./centmin.sh
#
###############################################################
KEYPRESS_PARAM='-s -n1 -p'   # Read a keypress without hitting ENTER.
		# -s means do not echo input.
		# -n means accept only N characters of input.
		# -p means echo the following prompt before reading input
ASKCMD="read $KEYPRESS_PARAM "
MACHINE_TYPE=`uname -m` # Used to detect if OS is 64bit or not.

CUR_DIR=`pwd` # Get current directory.
###############################################################
# FUNCTIONS

if [[ "$CENTOSVER" = '6.0' || "$CENTOSVER" = '6.1' || "$CENTOSVER" = '6.2' ]]; then
DOWNLOADAPP='axel -a'
WGETRETRY=''
AXELPHPTARGZ="-o php-${PHP_VERSION}.tar.gz"
AXELPHPUPGRADETARGZ="-o php-${phpver}.tar.gz"
else
DOWNLOADAPP='wget -c'
WGETRETRY='--tries=3'
AXELPHPTARGZ=''
AXELPHPUPGRADETARGZ=''
fi

if [ "${ARCH_OVERRIDE}" != '' ]
then
    ARCH=${ARCH_OVERRIDE}
else
    if [ ${MACHINE_TYPE} == 'x86_64' ];
    then
        ARCH='x86_64'
        MDB_ARCH='amd64'
    else
        ARCH='i386'
    fi
fi

ASK () {
keystroke=''
while [[ "$keystroke" != [yYnN] ]]
do
    $ASKCMD "$1" keystroke
    echo "$keystroke";
done

key=$(echo $keystroke)
}

# Setup Colours
black='\E[30;40m'
red='\E[31;40m'
green='\E[32;40m'
yellow='\E[33;40m'
blue='\E[34;40m'
magenta='\E[35;40m'
cyan='\E[36;40m'
white='\E[37;40m'

boldblack='\E[1;30;40m'
boldred='\E[1;31;40m'
boldgreen='\E[1;32;40m'
boldyellow='\E[1;33;40m'
boldblue='\E[1;34;40m'
boldmagenta='\E[1;35;40m'
boldcyan='\E[1;36;40m'
boldwhite='\E[1;37;40m'

Reset="tput sgr0"      #  Reset text attributes to normal
                       #+ without clearing screen.

cecho ()                     # Coloured-echo.
                             # Argument $1 = message
                             # Argument $2 = color
{
message=$1
color=$2
echo -e "$color$message" ; $Reset
return
}

function funct_centmininstall {

CHECKCENTMINMODINSTALL=`ls /etc/init.d | grep -E '(csf|lfd|nginx|php-fpm)'`
if [ ! -z "$CHECKCENTMINMODINSTALL" ]; then
echo ""
echo "Centmin Mod previous installation detected. "
echo ""
echo "If you are upgrading a server which already previously had Centmin Mod installed"
echo "you DO NOT need to run option #1, instead run option #4 & then #5 for upgrading"
echo "Nginx web server and upgrading PHP."
echo ""
echo "exiting script"
exit
fi

run_once ()
{
# If OpenVZ user add user/group 500 - else various folders and devices will end up with an odd user/group name for some reason
if [ -f /proc/user_beancounters ];
then
    groupadd 500
    useradd -g 500 -s /sbin/nologin -M 500
fi

ASK "Would you like to update any pre-installed software? (Recommended) [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "Let's do that then..."
    yum -q clean all
    yum -y update glibc\*
    yum -y update yum\* rpm\* python\*
    yum -q clean all
    yum -y update
fi

if [ ${ARCH} == 'x86_64' ];
then
    ASK "Would you like to exclude installation of 32bit Yum packages? (Recommended for 64bit CentOS) [y/n] "
    if [[ "$key" = [yY] ]];
    then
        mv /etc/yum.conf /etc/yum.bak
        cp $CUR_DIR/config/yum/yum.conf /etc/yum.conf
        echo "Your origional yum configuration has been backed up to /etc/yum.bak"
    else
        rm -rf $CUR_DIR/config/yum
    fi
fi

ASK "Would you like to secure /tmp and /var/tmp? (Highly recommended) [y/n] "   
if [[ "$key" = [yY] ]]; 
then
	echo "*************************************************"
	cecho "* Secured /tmp and /var/tmp" $boldgreen
	echo "*************************************************"

	rm -rf /tmp
	mkdir /tmp
	mount -t tmpfs -o rw,noexec,nosuid tmpfs /tmp
	chmod 1777 /tmp
	echo "tmpfs   /tmp    tmpfs   rw,noexec,nosuid        0       0" >> /etc/fstab
	rm -rf /var/tmp
	ln -s /tmp /var/tmp
fi

questions() {
	echo "**********************************************************"
            echo "  Questions for per app memory usage: Answer y or n and hit enter"
	echo "**********************************************************"
echo ""
read -p "MySQL Install: does this server have less than <=2048MB of memory installed ? [y/n]: " lessmem
echo ""
read -p "PHP Install: Does this server have less than <=2048MB of memory installed ? [y/n]: " lessphpmem
echo ""
read -p "Xcache Install: Does this server have less than <=2048MB of memory installed ? [y/n]:  " lessxcachemem
echo ""
read -p "APC Cache Install: Does this server have less than <=2048MB of memory installed ? [y/n]:  " lessapcmem
}
questions

yuminstall

ASK "Would you like to set the server localtime? [y/n] "   
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Setting preferred localtime for VPS" $boldgreen
    echo "*************************************************"
    rm -f /etc/localtime
    ln -s /usr/share/zoneinfo/$ZONEINFO /etc/localtime
    echo "Current date & time for the zone you selected is:"
    date
fi
}

# END FUNCTIONS
################################################################
# SCRIPT START
#
clear
cecho "**********************************************************************" $boldyellow
cecho "* Centmin, an nginx, MariaDB/MySQL, PHP & DNS Install script for CentOS" $boldgreen
cecho "* Version: $SCRIPT_VERSION - Date: $SCRIPT_DATE - $COPYRIGHT" $boldgreen
cecho "* Contributions by: $SCRIPT_MODIFICATION_AUTHOR" $boldgreen
cecho "**********************************************************************" $boldyellow
echo " "
cecho "This software comes with no warranty of any kind. You are free to use" $boldyellow
cecho "it for both personal and commercial use as licensed under the GPL." $boldyellow
echo " "
cecho "Please read the included readme.txt before using this script." $boldmagenta
echo " "
ASK "Would you like to continue? [y/n] "   
if [[ "$key" = [nN] ]];
then
    exit 0
fi

# Set LIBDIR
if [ ${ARCH} == 'x86_64' ];
then
    LIBDIR='lib64'
else
    LIBDIR='lib'
fi

DIR_TMP="/svr-setup"
if [ -a "$DIR_TMP" ];
then
	ASK "It seems that you have run this script before, would you like to start from after setting the timezone? [y/n] "
	if [[ "$key" = [nN] ]];
	then
		run_once
	fi
else
	mkdir /svr-setup
	run_once
fi

if [ -f /proc/user_beancounters ];
then
    cecho "OpenVZ system detected, NTP not installed" $boldgreen
else
    if [[ "$NTP_INSTALL" = [yY] ]]; 
    then
        echo "*************************************************"
        cecho "* Installing NTP (and syncing time)" $boldgreen
        echo "*************************************************"
        yum -y install ntp
        chkconfig --levels 235 ntpd on
        ntpdate pool.ntp.org
        echo "The date/time is now:"
        date
        echo "If this is correct, then everything is working properly"
        echo "*************************************************"
        cecho "* NTP installed" $boldgreen
        echo "*************************************************"
    fi
fi

if [[ "$NGINX_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing nginx" $boldgreen
    echo "*************************************************"

    # Disable Apache if installed
    if [ -f /etc/init.d/httpd ];
    then
      /sbin/service httpd stop
      chkconfig httpd off
    fi

    # Then install nginx
    cd /svr-setup

#######################################################
# check if custom open file descriptor limits already exist

LIMITSCONFCHECK=`grep '* hard nofile 65536' /etc/security/limits.conf`

if [[ -z $LIMITSCONFCHECK ]]; then

    # Set VPS hard/soft limits
    echo "* soft nofile 65536" >>/etc/security/limits.conf
    echo "* hard nofile 65536" >>/etc/security/limits.conf

fi # check if custom open file descriptor limits already exist

    # nginx Modules / Prerequisites
	cecho "Installing nginx Modules / Prerequisites..." $boldgreen

if [[ "$GPERFTOOLS_SOURCEINSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Source Install Google Perftools" $boldgreen
    echo "*************************************************"

    # Install libunwind
    echo "Compiling libunwind..."
    if [ -s libunwind-${LIBUNWIND_VERSION}.tar.gz ]; then
        cecho "libunwind ${LIBUNWIND_VERSION} Archive found, skipping download..." $boldgreen 
    else
        $DOWNLOADAPP http://download.savannah.gnu.org/releases/libunwind/libunwind-${LIBUNWIND_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf libunwind-${LIBUNWIND_VERSION}.tar.gz
    cd libunwind-${LIBUNWIND_VERSION}
    ./configure
    make$MAKETHREADS
    make install

    # Install google-perftools
    cd /svr-setup

    echo "Compiling google-perftools..."
    if [ -s google-perftools-${GPERFTOOLS_VERSION}.tar.gz ]; then
        cecho "google-perftools ${GPERFTOOLS_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://google-perftools.googlecode.com/files/google-perftools-${GPERFTOOLS_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf google-perftools-${GPERFTOOLS_VERSION}.tar.gz
    cd google-perftools-${GPERFTOOLS_VERSION}
    ./configure --enable-frame-pointers
    make$MAKETHREADS
    make install
    echo "/usr/local/lib" > /etc/ld.so.conf.d/usr_local_lib.conf
    /sbin/ldconfig

fi # GPERFTOOLS_SOURCE INSTALL 

    # Install OpenSSL
    cd /svr-setup

    echo "Compiling OpenSSL..."
    if [ -s openssl-${OPENSSL_VERSION}.tar.gz ]; then
        cecho "openssl ${OPENSSL_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://www.openssl.org/source/openssl-${OPENSSL_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf openssl-${OPENSSL_VERSION}.tar.gz
    cd openssl-${OPENSSL_VERSION}
    ./config --prefix=/usr/local --openssldir=/usr/local/ssl
    make
    make install

    ./config shared --prefix=/usr/local --openssldir=/usr/local/ssl
    make clean
    make
    make install

if [[ "$PCRE_SOURCEINSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Source Install PCRE" $boldgreen
    echo "*************************************************"

    # Install PCRE
    cd /svr-setup

    echo "Compiling PCRE..."
    if [ -s pcre-${PCRE_VERSION}.tar.gz ]; then
        cecho "pcre ${PCRE_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-${PCRE_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf pcre-${PCRE_VERSION}.tar.gz
    cd pcre-${PCRE_VERSION}
    ./configure
    make$MAKETHREADS
    make install

fi

if [ "$NGINX_OPENRESTY" == 'y' ]; then
funct_nginxmodules_openresty
else
funct_nginxmodules
fi

    # Install nginx
    cd /svr-setup

    echo "Compiling nginx..."
    if [ -s nginx-${NGINX_VERSION}.tar.gz ]; then
        cecho "nginx ${NGINX_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP "http://nginx.org/download/nginx-${NGINX_VERSION}.tar.gz" $WGETRETRY
    fi

    if [ ${MACHINE_TYPE} == 'x86_64' ];
    then
        MBIT='64'
    else
        MBIT='32'
    fi

    tar xvfz nginx-${NGINX_VERSION}.tar.gz
    cd nginx-${NGINX_VERSION}

if [ "$NGINX_OPENRESTY" == 'y' ]; then
funct_nginxconfigure_openresty
else
funct_nginxconfigure
fi

    make$MAKETHREADS
    make install

    groupadd nginx
    useradd -g nginx -d /home/nginx -s /sbin/nologin nginx
    chmod 0755 /home/nginx

#######################################################
# check if custom open file descriptor limits already exist

NGXLIMITSCONFCHECK=`grep 'nginx hard nofile 65536' /etc/security/limits.conf`

if [[ -z $NGXLIMITSCONFCHECK ]]; then

    # Set user nginx hard/soft limits
    echo "nginx soft nofile 65536" >>/etc/security/limits.conf
    echo "nginx hard nofile 65536" >>/etc/security/limits.conf
    ulimit -n 65536

fi # check if custom open file descriptor limits already exist

    mkdir /home/nginx/domains
    chmod 0771 /home/nginx/domains/
    mkdir -p /home/nginx/domains/demo.com/{public,private,log,backup}
    cp -R $CUR_DIR/htdocs/demo.com/* /home/nginx/domains/demo.com/public
    cp -R $CUR_DIR/htdocs/custom_errorpages/* /home/nginx/domains/demo.com/public
    chown -R nginx:nginx /home/nginx

    mkdir -p /usr/local/nginx/html
    mkdir -p /usr/local/nginx/conf/conf.d
    cp -R $CUR_DIR/htdocs/default/* /usr/local/nginx/html
    cp -R $CUR_DIR/htdocs/custom_errorpages/* /usr/local/nginx/html
    #rm -rf $CUR_DIR/htdocs
    cp -R $CUR_DIR/config/nginx/* /usr/local/nginx/conf
    cp $CUR_DIR/init/nginx /etc/init.d/nginx
    chmod +x /etc/init.d/nginx
    chkconfig --levels 235 nginx on

if [ -f /usr/local/nginx/html/phpi.php ]; then
# Randomize phpi.php filename
NPHP=$RANDOM
mv /usr/local/nginx/html/phpi.php /usr/local/nginx/html/${NPHP}_phpi.php
chown nginx:nginx /usr/local/nginx/html/${NPHP}_phpi.php
fi

# rackspace cloud servers block port 80 so need to allow it
iptables -I RH-Firewall-1-INPUT -p tcp --dport 80 -j ACCEPT

if [ ! -f /usr/local/nginx/conf/htpasswd ]; then

touch /usr/local/nginx/conf/htpasswd

fi

cp $CUR_DIR/config/htpasswdgen/htpasswd.py /usr/local/nginx/conf/htpasswd.py

funct_logrotate

    echo "*************************************************"
    cecho "* nginx installed, Apache disabled" $boldgreen
    echo "*************************************************"
fi

if [[ "$MDB_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing MariaDB " $boldgreen
    echo "*************************************************"

service mysqld stop

yum -y remove mysql mysql-libs

if [ ! -d /home/mysqltmp ]; then
mkdir /home/mysqltmp
chmod 1777 /home/mysqltmp
#chown mysql:mysql /home/mysqltmp/
fi

if [ -f /etc/my.cnf ]; then
cp /etc/my.cnf /etc/my.cnf-original
fi
#echo -e "\nCopying MariaDB my-mdb.cnf file to /etc/my.cnf\n"
#    cp $CUR_DIR/config/mysql/my-mdb.cnf /etc/my.cnf

    # The MariaDB mirror uses x86 and amd64 prefixes for rpm folders instead of i386/x84_64, so compensate for that...
    if [ ${ARCH} == 'x86_64' ];
    then
        MDB_ARCH='amd64'
    else
        MDB_ARCH='x86'
        ARCH='i386'
    fi

    cd /svr-setup

yum -y install perl-DBD-MySQL

service mysqld stop

yum -y remove mysql mysql-libs

echo

#read -p "Does this server have less than <=2048MB of memory installed ? [y/n]: " lessmem

#echo
#echo

if [[ "$lessmem" = [yY] ]]; then

echo $lessmem

echo -e "\nCopying MariaDB my-mdb-min.cnf file to /etc/my.cnf\n"
    cp $CUR_DIR/config/mysql/my-mdb-min.cnf /etc/my.cnf

else

echo $lessmem

echo -e "\nCopying MariaDB my-mdb.cnf file to /etc/my.cnf\n"
    cp $CUR_DIR/config/mysql/my-mdb.cnf /etc/my.cnf

fi

    if [ -s MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-${MDB_VERONLY}/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm $WGETRETRY
    fi

    if [ -s MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-${MDB_VERONLY}/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm $WGETRETRY
    fi

    if [ -s MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-${MDB_VERONLY}/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm $WGETRETRY
    fi

    if [ -s MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-${MDB_VERONLY}/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm $WGETRETRY
    fi

    if [ -s MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm ]; then
        cecho "MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://mirror.aarnet.edu.au/pub/MariaDB/mariadb-${MDB_VERONLY}/kvm-rpm-centos5-${MDB_ARCH}/rpms/MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm $WGETRETRY
    fi

    rpm -i MariaDB-shared-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-client-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-devel-${MDB_VERSION}.el5.${ARCH}.rpm

#killall mysqld_safe
#killall mysqld
gzip /var/lib/mysql/{ibdata1,ib_logfile0,ib_logfile1}

    rpm -i MariaDB-server-${MDB_VERSION}.el5.${ARCH}.rpm
    rpm -i MariaDB-test-${MDB_VERSION}.el5.${ARCH}.rpm

    yum -y install perl-DBD-MySQL
    yum -q clean all

    cd /root

    if [ -s mysqlreport ]; then
        cecho "mysqlreport found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://centminmod.com/centminmodparts/mysqlreport/mysqlreport $WGETRETRY
    fi

    if [ -s mysqltuner.pl ]; then
        cecho "mysqltuner.pl found, skipping download..." $boldgreen
    else
        wget -c http://centminmod.com/centminmodparts/mysqltuner/mysqltuner.txt -O mysqltuner.pl --tries=3
    fi



    chmod +x mysqlreport mysqltuner.pl

    cd /svr-setup

   # chkconfig --levels 235 mysql on
   # service mysql restart

if [[ ! `grep exclude /etc/yum.conf` ]]; then

cecho "Can't find exclude line in /etc/yum.conf... adding exclude line for mysql*" $boldgreen

echo "exclude=mysql*">> /etc/yum.conf

else

cecho "exclude line exists... adding exclude line for mysql*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686/exclude=\*.i386 \*.i586 \*.i686 mysql\*/" /etc/yum.conf

fi

    echo "*************************************************"
    cecho "* Starting MariaDB Secure Installation" $boldgreen
    echo "*************************************************"

mysql_upgrade --force --verbose
service mysql restart
mysql_secure_installation
    
    echo "*************************************************"
    cecho "* MariaDB installed" $boldgreen
    echo "*************************************************"
    
    /etc/init.d/mysql stop
fi

if [[ "$MDB_YUMREPOINSTALL" = [yY] ]]; 
then

MDBVERYUMCHECK=`yum info MariaDB-server | grep -E '(^Version|installed)'`

if [[ ! -z $MDBVERYUMCHECK ]]; then

	echo ""
    echo "*************************************************"
    cecho "Previous MariaDB Server YUM install detected " $boldgreen
    echo "*************************************************"
	echo "MariaDB-server version:"
	cat $MDBVERYUMCHECK
	echo ""

fi # MDBVERYUMCHECK

    echo "*************************************************"
    cecho "* Installing MariaDB via CentOS Yum Repo " $boldgreen
    echo "*************************************************"

#yum -y remove mysql mysql-libs
if [ -f /etc/my.cnf ]; then
cp /etc/my.cnf /etc/my.cnf-original
fi

    cd /svr-setup

yum -y install perl-DBD-MySQL

service mysqld stop

yum -y remove mysql mysql-libs

    if [ -s ourdelta-release-5-1.noarch.rpm ]; then
        cecho "ourdelta-release-5-1.noarch.rpm found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://master.ourdelta.org/yum/CentOS-MariaDB52/ourdelta-release-5-1.noarch.rpm $WGETRETRY
    fi

rpm -ivh ourdelta-release-5-1.noarch.rpm

echo

#read -p "Does this server have less than <=2048MB of memory installed ? [y/n]: " lessmem

#echo
#echo

if [[ "$lessmem" = [yY] ]]; then

echo $lessmem

echo -e "\nCopying MariaDB my-mdb-min.cnf file to /etc/my.cnf\n"
    cp $CUR_DIR/config/mysql/my-mdb-min.cnf /etc/my.cnf

else

echo $lessmem

echo -e "\nCopying MariaDB my-mdb.cnf file to /etc/my.cnf\n"
    cp $CUR_DIR/config/mysql/my-mdb.cnf /etc/my.cnf

fi

yum -y install MariaDB-client MariaDB-devel MariaDB-shared MariaDB-test

yum -y install sysstat

MYSQLLIBS=`rpm -qa | grep -i mysql-libs`

rpm --nodeps -e $MYSQLLIBS

#killall mysqld_safe
#killall mysqld
gzip /var/lib/mysql/{ibdata1,ib_logfile0,ib_logfile1}

yum -y install MariaDB-server

yum -y install perl-DBD-MySQL
yum -q clean all


    cd /root

    if [ -s mysqlreport ]; then
        cecho "mysqlreport found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://centminmod.com/centminmodparts/mysqlreport/mysqlreport $WGETRETRY
    fi

    if [ -s mysqltuner.pl ]; then
        cecho "mysqltuner.pl found, skipping download..." $boldgreen
    else
        wget -c http://centminmod.com/centminmodparts/mysqltuner/mysqltuner.txt -O mysqltuner.pl --tries=3
    fi

    chmod +x mysqlreport mysqltuner.pl

    cd /svr-setup

    #chkconfig --levels 235 mysql on
    #service mysql restart

if [[ ! `grep exclude /etc/yum.conf` ]]; then

cecho "Can't find exclude line in /etc/yum.conf... adding exclude line for mysql*" $boldgreen

echo "exclude=mysql*">> /etc/yum.conf

else

cecho "exclude line exists... adding exclude line for mysql*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686/exclude=\*.i386 \*.i586 \*.i686 mysql\*/" /etc/yum.conf

fi

    echo "*************************************************"
    cecho "* Starting MariaDB Secure Installation" $boldgreen
    echo "*************************************************"

mysql_upgrade --force --verbose
service mysql restart
mysql_secure_installation
    
    echo "*************************************************"
    cecho "* MariaDB installed" $boldgreen
    echo "*************************************************"
    
    /etc/init.d/mysql stop
fi

if [[ "$MYSQL_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing MySQL" $boldgreen
    echo "*************************************************"
    yum -y install mysql mysql-devel mysql-server perl-DBD-MySQL

if [ -f /etc/my.cnf ]; then
cp /etc/my.cnf /etc/my.cnf-original
fi
    cp -R $CUR_DIR/config/mysql/my.cnf /etc/my.cnf

    cd /root

    if [ -s mysqlreport ]; then
        cecho "mysqlreport found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://centminmod.com/centminmodparts/mysqlreport/mysqlreport $WGETRETRY
    fi

    if [ -s mysqltuner.pl ]; then
        cecho "mysqltuner.pl found, skipping download..." $boldgreen
    else
        wget -c http://centminmod.com/centminmodparts/mysqltuner/mysqltuner.txt -O mysqltuner.pl --tries=3
    fi

    chmod +x mysqlreport mysqltuner.pl

    cd /svr-setup

    chkconfig --levels 235 mysqld on
    /etc/init.d/mysqld start

    echo "*************************************************"
    cecho "* Starting MySQL Secure Installation" $boldgreen
    echo "*************************************************"
    mysql_secure_installation
    echo "*************************************************"
    cecho "* MySQL installed" $boldgreen
    echo "*************************************************"

    /etc/init.d/mysqld stop
fi

if [[ "$PHP_INSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Installing PHP" $boldgreen
    echo "*************************************************"

funct_centos6check

    export PHP_AUTOCONF=/usr/bin/autoconf-2.13
    export PHP_AUTOHEADER=/usr/bin/autoheader-2.13

    cd /svr-setup

    # IMPORTANT Erase any PHP installations first, otherwise conflicts may arise
    yum -y erase php*

    if [ -s php-${PHP_VERSION}.tar.gz ]; then
        cecho "php ${PHP_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP ${PHP_MIRRORURL}/get/php-${PHP_VERSION}.tar.gz/from/this/mirror $AXELPHPTARGZ $WGETRETRY
    fi

    tar xzvf php-${PHP_VERSION}.tar.gz

    cd php-${PHP_VERSION}

    ./buildconf --force
    mkdir fpm-build && cd fpm-build

    mkdir -p /usr/${LIBDIR}/mysql
    ln -s /usr/${LIBDIR}/libmysqlclient.so /usr/${LIBDIR}/mysql/libmysqlclient.so

funct_phpconfigure

    make$MAKETHREADS
    make install

    cd ../

#######################################################
# check to see if centmin custom php.ini already in place

CUSTOMPHPINICHECK=`grep 'realpath_cache_size = 1024k' /usr/local/lib/php.ini`

if [[ -z $CUSTOMPHPINICHECK ]]; then

    cp -f php.ini-production /usr/local/lib/php.ini
    chmod 644 /usr/local/lib/php.ini

phpsededit

fi # check to see if centmin custom php.ini already in place


echo

#read -p "Does this server have less than <=2048MB of memory installed ? [y/n]: " lessphpmem

#echo
#echo

if [[ "$lessphpmem" = [yY] ]]; then

echo $lessphpmem

echo -e "\nCopying php-fpm-min.conf /usr/local/etc/php-fpm.conf\n"
    cp $CUR_DIR/config/php-fpm/php-fpm-min.conf /usr/local/etc/php-fpm.conf

else

echo $lessphpmem

echo -e "\nCopying php-fpm.conf /usr/local/etc/php-fpm.conf\n"
    cp $CUR_DIR/config/php-fpm/php-fpm.conf /usr/local/etc/php-fpm.conf

fi


    cp $CUR_DIR/init/php-fpm /etc/init.d/php-fpm

    chmod +x /etc/init.d/php-fpm

    mkdir -p /var/run/php-fpm
    touch /var/run/php-fpm/php-fpm.pid
    chown nginx:nginx /var/run/php-fpm

    mkdir /var/log/php-fpm/
    touch /var/log/php-fpm/www-error.log
    chmod 0666 /var/log/php-fpm/www-error.log

    #chown -R root:nginx /var/lib/php/session/
    chkconfig --levels 235 php-fpm on
    /etc/init.d/php-fpm start

if [[ `grep exclude /etc/yum.conf` && $MDB_INSTALL = y ]]; then

cecho "exclude line exists... adding mysql* php*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686 mysql\*/exclude=\*.i386 \*.i586 \*.i686 mysql\* php\*/" /etc/yum.conf

sed -i "s/exclude=mysql\*/exclude=mysql\* php\*/" /etc/yum.conf

elif [[ `grep exclude /etc/yum.conf` ]]; then

cecho "exclude line exists... adding php*" $boldgreen

sed -i "s/exclude=\*.i386 \*.i586 \*.i686/exclude=\*.i386 \*.i586 \*.i686 php\*/" /etc/yum.conf 

fi


if [[ ! `grep exclude /etc/yum.conf` && $MDB_INSTALL = y ]]; then

cecho "Can't find exclude line in /etc/yum.conf.. adding exclude line for mysql* php*" $boldgreen

echo "exclude=mysql* php*">> /etc/yum.conf

elif [[ ! `grep exclude /etc/yum.conf` ]]; then

cecho "Can't find exclude line in /etc/yum.conf... adding exclude line for php*" $boldgreen

echo "exclude=php*">> /etc/yum.conf

fi

funct_logphprotate

    echo "*************************************************"
    cecho "* PHP installed" $boldgreen
    echo "*************************************************"
fi

xcacheinstall_ask

if [ "$xcacheinstallcheck" != 'y' ]; then
    #cecho "* If you installed Xcache, DO NOT install APC" $boldgreen

ASK "Install APC? (By default uses 32MB RAM) [y/n] "
if [[ "$key" = [yY] ]];
then
funct_apcsourceinstall
fi
fi # xcacheinstallcheck

if [[ "$SENDMAIL_INSTALL" = [yY] ]]; 
then

	if [[ ! -f /etc/init.d/postfix ]]; then
	echo "*************************************************"
	cecho "* Installing sendmail" $boldgreen
	echo "*************************************************"
	yum -y -q install sendmail mailx sendmail-cf
	chkconfig --levels 235 sendmail on
	funct_sendmailmc
	#/etc/init.d/sendmail start
	echo "*************************************************"
	cecho "* sendmail installed" $boldgreen
	echo "*************************************************"
	fi

else

	echo "*************************************************"
	cecho "Postfix already detected, sendmail install aborted" $boldgreen
	echo "*************************************************"

fi

ASK "Install Memcached Server? (default uses 8MB RAM each) [y/n] "
if [[ "$key" = [yY] ]];
then

funct_memcachedreinstall

cd /svr-setup

#######################################################
# check /etc/init.d/memcached

if [[ ! -f /etc/init.d/memcached ]]; then

echo ""
echo -n "Install how many Memcached servers ? 1 or 2 ?: "
read nomemcachedservers

if [[ "$nomemcachedservers" = '1' ]]; then

cp $CUR_DIR/config/memcached/memcached /etc/init.d/memcached

fi

if [[ "$nomemcachedservers" = '2' ]]; then

cp $CUR_DIR/config/memcached/memcached2 /etc/init.d/memcached

fi

fi # check /etc/init.d/memcached

chmod +x /etc/init.d/memcached
chkconfig --add memcached
chkconfig --level 345 memcached on
service memcached start

    cecho "Compiling PHP memcache extension..." $boldgreen

cd /svr-setup
tar -xvf memcache-${MEMCACHE_VERSION}.tgz
cd memcache-${MEMCACHE_VERSION}
/usr/local/bin/phpize
./configure --enable-memcache --with-php-config=/usr/local/bin/php-config
make && make install

#######################################################
# check to see if memcache.so already loaded in php.ini

MEMCACHESOCHECK=`grep 'memcache.so' /usr/local/lib/php.ini`
PHPEXTDIR=`cat /usr/local/bin/php-config | awk '/^extension_dir/ {extdir=$1} END {gsub(/\047|extension_dir|=|)/,"",extdir); print extdir}'`

if [[ -z $MEMCACHESOCHECK ]]; then

echo "" >> /usr/local/lib/php.ini
echo "extension=${PHPEXTDIR}/memcache.so" >> /usr/local/lib/php.ini

else

echo ""
echo "memcache.so already loaded in /usr/local/lib/php.ini"
echo "$MEMCACHESOCHECK"
echo ""

fi # memcache.so check

/etc/init.d/php-fpm restart

#######################################################
# check to see if memcache.php already exists

if [[ ! -f /usr/local/nginx/html/memcache.php ]]; then

    echo ""
    echo "*************************************************"
    cecho "Setup memcached.php admin page ..." $boldgreen
    echo "*************************************************"

cp -a memcache.php /usr/local/nginx/html
chown -R nginx:nginx /usr/local/nginx/html
chmod 644 /usr/local/nginx/html/memcache.php

sed -i "s/'ADMIN_USERNAME','memcache'/'ADMIN_USERNAME','memcacheuser'/g" /usr/local/nginx/html/memcache.php
sed -i "s/'ADMIN_PASSWORD','password'/'ADMIN_PASSWORD','memcachepass'/g" /usr/local/nginx/html/memcache.php

if [[ "$nomemcachedservers" = '1' ]]; then

sed -i "s/mymemcache-server1:11211/localhost:11211/g" /usr/local/nginx/html/memcache.php

sed -i "s/\$MEMCACHE_SERVERS\[] = 'mymemcache-server2:11211'; \/\/ add more as an array/\/\/ mymemcache-server2:/g" /usr/local/nginx/html/memcache.php

fi

if [[ "$nomemcachedservers" = '2' ]]; then

sed -i "s/mymemcache-server1:11211/localhost:11211/g" /usr/local/nginx/html/memcache.php

sed -i "s/mymemcache-server2:11211/localhost:11212/g" /usr/local/nginx/html/memcache.php

fi

cecho "Setup Memcached Server Admin Login Details for /usr/local/nginx/html/memcache.php" $boldgreen
echo -n "(Type username your want to set and press Enter): "
read memcacheduser
echo -n "(Type password your want to set and press Enter): "
read memcachedpassword

cecho "current memcached username: `grep "'ADMIN_USERNAME','memcacheuser'" /usr/local/nginx/html/memcache.php | sed -e "s/define('ADMIN_USERNAME','//" | sed -e 's/\/\/ Admin Username//' | sed 's/^[ \t]*//;s/[ \t]*$//' | sed -e "s/');//"`" $boldgreen

cecho "current memcached password: `grep "'ADMIN_PASSWORD','memcachepass'" /usr/local/nginx/html/memcache.php | sed -e "s/define('ADMIN_PASSWORD','//" | sed -e 's/\/\/ Admin Password//' | sed 's/^[ \t]*//;s/[ \t]*$//' | sed -e "s/');//"`" $boldgreen

sed -i "s/'ADMIN_USERNAME','memcacheuser'/'ADMIN_USERNAME','${memcacheduser}'/g" /usr/local/nginx/html/memcache.php
sed -i "s/'ADMIN_PASSWORD','memcachepass'/'ADMIN_PASSWORD','${memcachedpassword}'/g" /usr/local/nginx/html/memcache.php

cecho "new memcached username: ${memcacheduser}" $boldgreen
cecho "new memcached password: ${memcachedpassword}" $boldgreen

    echo "*************************************************"
    cecho "* memcache.php admin page installed" $boldgreen
    echo "*************************************************"

else

    echo "*************************************************"
    cecho "memcache.php admin page already installed" $boldgreen
    echo "*************************************************"

fi # memcache.php file check

    echo "*************************************************"
    cecho "* memcached installed" $boldgreen
    echo "*************************************************"

fi

nsdinstall

csfinstalls

ASK "Install Siege Benchmark script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing Siege Benchmark... " $boldgreen
    echo "*************************************************"
    echo "Installing..."

    cd /svr-setup

    if [ -s siege-latest.tar.gz ]; then
        cecho "siege-latest Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://www.joedog.org/pub/siege/siege-latest.tar.gz $WGETRETRY
    fi

    if [ -s sproxy-latest.tar.gz ]; then
        cecho "sproxy-latest Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://www.joedog.org/pub/sproxy/sproxy-latest.tar.gz $WGETRETRY
    fi

    tar -xzf siege-latest.tar.gz
    cd siege-2.7*
    ./configure
    make$MAKETHREADS
    make install
    mkdir /usr/local/var/

    sed -i 's/# failures =/failures = 2048/g' /usr/local/etc/siegerc

    cd /svr-setup

    tar -xzf sproxy-latest.tar.gz
    cd sproxy-1.02
    ./configure
    make$MAKETHREADS
    make install

    echo "*************************************************"
    cecho "* Siege Benchmark installed " $boldgreen
    echo "*************************************************"
fi

ASK "Install Python Update ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Installing Python... " $boldgreen
    echo "*************************************************"
    echo "Installing..."

cd /svr-setup

if [ -s Python-${PYTHON_VERSION}.tgz ]; then
  cecho "Python-${PYTHON_VERSION}.tgz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: Python-${PYTHON_VERSION}.tgz not found!!!download now......"
        $DOWNLOADAPP http://www.python.org/ftp/python/${PYTHON_VERSION}/Python-${PYTHON_VERSION}.tgz $WGETRETRY
fi

if [ -s setuptools-0.6c11-py2.7.egg ]; then
  cecho "setuptools-0.6c11-py2.7.egg Archive found, skipping download..." $boldgreen
  else
  cecho "Error: setuptools-0.6c11-py2.7.egg not found!!!download now......"
        $DOWNLOADAPP http://pypi.python.org/packages/2.7/s/setuptools/setuptools-0.6c11-py2.7.egg $WGETRETRY
fi

cecho "Compiling Python..." $boldgreen


tar xvfz Python-${PYTHON_VERSION}.tgz
cd Python-${PYTHON_VERSION}
./configure --prefix=/opt/python${PYTHON_VERSION} --with-threads --enable-shared
make
make install

#######################################################
# check /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf

if [[ ! -f /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf ]]; then

touch /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf
echo "/opt/python${PYTHON_VERSION}/lib/" >> /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf
ldconfig

fi # check /etc/ld.so.conf.d/opt-python${PYTHON_VERSION}.conf

ln -sf /opt/python${PYTHON_VERSION}/bin/python /usr/bin/python2.7

cd /svr-setup

sh setuptools-0.6c11-py2.7.egg --prefix=/opt/python${PYTHON_VERSION}

/opt/python${PYTHON_VERSION}/bin/easy_install pip

ln -sf /opt/python${PYTHON_VERSION}/bin/pip /usr/bin/pip
ln -sf /opt/python${PYTHON_VERSION}/bin/virtualenv /usr/bin/virtualenv

#######################################################
# check python alias setup

PYTHONALIASCHECK=`grep 'alias python=/opt/python2.7.2/bin/python' ~/.bash_profile`

if [[ -z $PYTHONALIASCHECK ]]; then

echo "alias python=/opt/python${PYTHON_VERSION}/bin/python" >> ~/.bash_profile
echo "alias python2.7=/opt/python${PYTHON_VERSION}/bin/python" >> ~/.bash_profile
echo "PATH=$PATH:/opt/python2.7/bin" >> ~/.bash_profile
source ~/.bash_profile

fi # check python alias setup

#cd /opt/python2.7.1/bin
#./easy_install ElementTree
#./easy_install Markdown
#./easy_install html5lib
#./easy_install python-openid

    echo "*************************************************"
    cecho "* Python Update installed " $boldgreen
    echo "*************************************************"
fi
if [ -f $CUR_DIR/Extras/nginx-update.sh ];
then
    chmod +x $CUR_DIR/Extras/nginx-update.sh
fi

echo " "

ASK "Add script shortcuts (as shown in command_shortcuts.txt) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    cecho "**********************************************************************" $boldgreen
    cecho "* Add cmd shortcuts for php.ini, my.cnf, php-fpm.conf, nginx.conf and virtual.conf " $boldgreen
    cecho "* Edit php.ini = phpedit " $boldgreen
    cecho "* Edit my.cnf = mycnf " $boldgreen
    cecho "* Edit php-fpm.conf = fpmconf " $boldgreen
    cecho "* Edit nginx.conf = nginxconf " $boldgreen
    cecho "* Edit virtual.conf = vhostconf " $boldgreen
    cecho "* nginx stop/start/restart = ngxstop/ngxstart/ngxrestart " $boldgreen
    cecho "* php-fpm stop/start/restart = fpmstop/fpmstart/fpmrestart " $boldgreen
    cecho "* mysql stop/start/restart = mysqlstop/mysqlstart/mysqlrestart " $boldgreen
    cecho "* nginx + php-fpm stop/start/restart = npstop/npstart/nprestart " $boldgreen
    cecho "* memcached stop/start/restart = memcachedstop/memcachedstart/memcachedrestart " $boldgreen
    cecho "* csf stop/start/restart = csfstop/csfstart/csfrestart " $boldgreen
    cecho "**********************************************************************" $boldgreen

    echo "nano -w /usr/local/lib/php.ini" > /usr/bin/phpedit ; chmod 700 /usr/bin/phpedit
    echo "nano -w /etc/my.cnf" >/usr/bin/mycnf ; chmod 700 /usr/bin/mycnf
    echo "nano -w /usr/local/etc/php-fpm.conf" >/usr/bin/fpmconf ; chmod 700 /usr/bin/fpmconf
    echo "nano -w /usr/local/nginx/conf/nginx.conf" >/usr/bin/nginxconf ; chmod 700 /usr/bin/nginxconf
    echo "nano -w /usr/local/nginx/conf/conf.d/virtual.conf" >/usr/bin/vhostconf ; chmod 700 /usr/bin/vhostconf
echo "nano -w /usr/local/nginx/conf/php.conf" >/usr/bin/phpinc ; chmod 700 /usr/bin/phpinc
echo "nano -w /usr/local/nginx/conf/drop.conf" >/usr/bin/dropinc ; chmod 700 /usr/bin/dropinc
echo "nano -w /usr/local/nginx/conf/staticfiles.conf" >/usr/bin/statfilesinc ; chmod 700 /usr/bin/statfilesinc

    echo "service nginx stop" >/usr/bin/ngxstop ; chmod 700 /usr/bin/ngxstop
    echo "service nginx start" >/usr/bin/ngxstart ; chmod 700 /usr/bin/ngxstart
    echo "service nginx restart" >/usr/bin/ngxrestart ; chmod 700 /usr/bin/ngxrestart
    echo "service php-fpm stop" >/usr/bin/fpmstop ; chmod 700 /usr/bin/fpmstop
    echo "service php-fpm start" >/usr/bin/fpmstart ; chmod 700 /usr/bin/fpmstart
    echo "service php-fpm restart" >/usr/bin/fpmrestart ; chmod 700 /usr/bin/fpmrestart

if [ -f /etc/init.d/mysql ]; then

    echo "service mysql stop" >/usr/bin/mysqlstop ; chmod 700 /usr/bin/mysqlstop
    echo "service mysql start" >/usr/bin/mysqlstart ; chmod 700 /usr/bin/mysqlstart
    echo "service mysql restart" >/usr/bin/mysqlrestart ; chmod 700 /usr/bin/mysqlrestart

elif [ -f /etc/init.d/mysqld ]; then

    echo "service mysqld stop" >/usr/bin/mysqlstop ; chmod 700 /usr/bin/mysqlstop
    echo "service mysqld start" >/usr/bin/mysqlstart ; chmod 700 /usr/bin/mysqlstart
    echo "service mysqld restart" >/usr/bin/mysqlrestart ; chmod 700 /usr/bin/mysqlrestart

fi
    echo "service nginx stop;service php-fpm stop" >/usr/bin/npstop ; chmod 700 /usr/bin/npstop
    echo "service nginx start;service php-fpm start" >/usr/bin/npstart ; chmod 700 /usr/bin/npstart
    echo "service nginx restart;service php-fpm restart" >/usr/bin/nprestart ; chmod 700 /usr/bin/nprestart

if [ -f /usr/local/bin/memcached ]; then
    echo "service memcached stop" >/usr/bin/memcachedstop ; chmod 700 /usr/bin/memcachedstop
    echo "service memcached start" >/usr/bin/memcachedstart ; chmod 700 /usr/bin/memcachedstart
    echo "service memcached restart" >/usr/bin/memcachedrestart ; chmod 700 /usr/bin/memcachedrestart
fi

if [ -f /usr/sbin/csf ]; then
    echo "service csf stop" >/usr/bin/csfstop ; chmod 700 /usr/bin/csfstop
    echo "service csf start" >/usr/bin/csfstart ; chmod 700 /usr/bin/csfstart
    echo "service csf restart" >/usr/bin/csfrestart ; chmod 700 /usr/bin/csfrestart
fi

SUHOSINCHECK=`grep 'extension=suhosin.so' /usr/local/lib/php.ini `
if [ ! -z "$SUHOSINCHECK" ]; then
    echo "sed -i 's/;extension=suhosin.so/extension=suhosin.so/g' /usr/local/lib/php.ini; fpmrestart; php -v" >/usr/bin/suhosinon ; chmod 700 /usr/bin/suhosinon
    echo "sed -i 's/extension=suhosin.so/;extension=suhosin.so/g' /usr/local/lib/php.ini; fpmrestart; php -v" >/usr/bin/suhosinoff ; chmod 700 /usr/bin/suhosinoff
fi

fi

echo " "

cecho "**********************************************************************" $boldgreen
cecho "* Starting Services..." $boldgreen
cecho "**********************************************************************" $boldgreen
if [[ "$NSD_INSTALL" = [yY] ]]; 
then
    /etc/init.d/nsd start
fi

if [ -f /etc/init.d/ntpd ];
then
    /etc/init.d/ntpd start
fi

if [[ "$NGINX_INSTALL" = [yY] ]]; 
then
    /etc/init.d/nginx start
fi

if [[ "$MDB_INSTALL" = [yY] || "$MDB_YUMREPOINSTALL" = [yY] ]]; 
then
    /etc/init.d/mysql start
fi

if [[ "$MYSQL_INSTALL" = [yY] ]]; 
then
    /etc/init.d/mysqld start
fi
echo " "

cecho "**********************************************************************" $boldgreen
cecho "* Adding nginx-update and nginx-vhost commands..." $boldgreen
cecho "**********************************************************************" $boldgreen

cp -R $CUR_DIR/Extras/nginx-update.sh /sbin/nginx-update
cp -R $CUR_DIR/Extras/nginx-vhost.sh /sbin/nginx-vhost

chmod +x /sbin/nginx-update
chmod +x /sbin/nginx-vhost

cecho "**********************************************************************" $boldgreen
cecho "* Added nginx-update and nginx-vhost commands!" $boldgreen
cecho "**********************************************************************" $boldgreen

echo " "

cecho "**********************************************************************" $boldgreen
cecho "* Installation complete, congratulations!" $boldgreen
cecho "* For security reasons we would recommend deleting this script." $boldgreen
cecho "* " $boldgreen
cecho "* We would highly recommend that you reboot your server." $boldgreen
cecho "* " $boldgreen
cecho "* Enjoy CentOS  -  BTCentral" $boldgreen
cecho "**********************************************************************" $boldgreen

cd

if [[ "$ENABLE_MENU" != [yY] ]]; then

ASK "Do would you like to run script cleanup (Highly recommended) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    rm -rf /svr-setup
    rm -rf $CUR_DIR/config
    rm -rf $CUR_DIR/init
    rm -rf $CUR_DIR/sysconfig
    echo "Temporary files/folders removed"
fi

ASK "Do you want to delete this script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Deleting Centmin script... " $boldgreen
    echo "*************************************************"
    echo "Removing..."

rm -f $0

    echo "*************************************************"
    cecho "* Centmin script deleted" $boldgreen
    echo "*************************************************"
fi

fi

funct_openvz_stacksize

    echo "*************************************************"
    cecho "* Running updatedb command. Please wait...." $boldgreen
    echo "*************************************************"

updatedb

}


#####################################################################
#####################################################################
# functions

function funct_centos6check {


if [[ "$CENTOSVER" == '5.6' || "$CENTOSVER" == '5.7'|| "$CENTOSVER" == '5.8' || "$CENTOSVER" == '6.0' || "$CENTOSVER" == '6.1' || "$CENTOSVER" == '6.2' ]]; then

MCRYPT=" --with-mcrypt"

else

MCRYPT=""

fi

}

function funct_nginxupgrade {

cecho "**********************************************************************" $boldyellow
cecho "* Nginx Update script - Included in Centmin Extras" $boldgreen
cecho "* Version: $SCRIPT_VERSION - Date: $SCRIPT_DATE - $COPYRIGHT" $boldgreen
cecho "**********************************************************************" $boldyellow
echo " "
cecho "This software comes with no warranty of any kind. You are free to use" $boldyellow
cecho "it for both personal and commercial use as licensed under the GPL." $boldyellow
echo " "
ASK "Nginx Upgrade - Would you like to continue? [y/n] "   
if [[ "$key" = [nN] ]];
then
    exit 0
fi

DIR_TMP="/svr-setup"
if [ ! -d "$DIR_TMP" ]; then
mkdir /svr-setup
fi

funct_mktempfile

if [ ! -f /etc/init.d/nginx ]; then
    cp $CUR_DIR/init/nginx /etc/init.d/nginx
    chmod +x /etc/init.d/nginx
    chkconfig --levels 235 nginx on
fi

echo -n "Install which version of Nginx? (version i.e. 1.0.6): "
read ngver

# Backup Nginx CONF
if [ "$NGINXBACKUP" == 'y' ]; then
nginxbackup
fi

    echo "*************************************************"
    cecho "* Updating nginx" $boldgreen
    echo "*************************************************"

    cd /svr-setup

    # nginx Modules / Prerequisites
	cecho "Installing nginx Modules / Prerequisites..." $boldgreen

if [[ "$GPERFTOOLS_SOURCEINSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Source Upgrade Google Perftools" $boldgreen
    echo "*************************************************"

    # Install libunwind
    echo "Compiling libunwind..."
    if [ -s libunwind-${LIBUNWIND_VERSION}.tar.gz ]; then
        cecho "libunwind ${LIBUNWIND_VERSION} Archive found, skipping download..." $boldgreen 
    else
        $DOWNLOADAPP http://download.savannah.gnu.org/releases/libunwind/libunwind-${LIBUNWIND_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf libunwind-${LIBUNWIND_VERSION}.tar.gz
    cd libunwind-${LIBUNWIND_VERSION}
    make clean
    ./configure
    make$MAKETHREADS
    make install

    # Install google-perftools
    cd /svr-setup

    echo "Compiling google-perftools..."
    if [ -s google-perftools-${GPERFTOOLS_VERSION}.tar.gz ]; then
        cecho "google-perftools ${GPERFTOOLS_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://google-perftools.googlecode.com/files/google-perftools-${GPERFTOOLS_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf google-perftools-${GPERFTOOLS_VERSION}.tar.gz
    cd google-perftools-${GPERFTOOLS_VERSION}
    make clean
    ./configure --enable-frame-pointers
    make$MAKETHREADS
    make install
    #echo "/usr/local/lib" > /etc/ld.so.conf.d/usr_local_lib.conf
    #/sbin/ldconfig

fi # GPERFTOOL_SOURCEINSTALL

    # Install OpenSSL
    cd /svr-setup
    echo "Compiling OpenSSL..."
    if [ -s openssl-${OPENSSL_VERSION}.tar.gz ]; then
        cecho "openssl ${OPENSSL_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP http://www.openssl.org/source/openssl-${OPENSSL_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf openssl-${OPENSSL_VERSION}.tar.gz
    cd openssl-${OPENSSL_VERSION}
    make clean
    ./config --prefix=/usr/local --openssldir=/usr/local/ssl
    make
    make install

    ./config shared --prefix=/usr/local --openssldir=/usr/local/ssl
    make clean
    make
    make install

if [[ "$PCRE_SOURCEINSTALL" = [yY] ]]; 
then
    echo "*************************************************"
    cecho "* Source Install PCRE" $boldgreen
    echo "*************************************************"

    # Install PCRE
    cd /svr-setup

    echo "Compiling PCRE..."
    if [ -s pcre-${PCRE_VERSION}.tar.gz ]; then
        cecho "pcre ${PCRE_VERSION} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP ftp://ftp.csx.cam.ac.uk/pub/software/programming/pcre/pcre-${PCRE_VERSION}.tar.gz $WGETRETRY
    fi

    tar xvzf pcre-${PCRE_VERSION}.tar.gz
    cd pcre-${PCRE_VERSION}
    make clean
    ./configure
    make$MAKETHREADS
    make install

fi

if [ "$NGINX_OPENRESTY" == 'y' ]; then
funct_nginxmodules_openresty
else
funct_nginxmodules
fi

    # Install nginx
    cd /svr-setup

    echo "Compiling nginx..."
    if [ -s nginx-${ngver}.tar.gz ]; then
        cecho "nginx ${ngver} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP "http://nginx.org/download/nginx-${ngver}.tar.gz" $WGETRETRY
    fi

    tar xvfz nginx-${ngver}.tar.gz
    cd nginx-${ngver}
    make clean

if [ "$NGINX_OPENRESTY" == 'y' ]; then
funct_nginxconfigure_openresty
else
funct_nginxconfigure
fi

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, Nginx configure failed\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: Nginx configure ok\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	fi

# error check
################

    make

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, Nginx make failed\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: Nginx make ok\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	fi

# error check
################

/etc/init.d/nginx stop
sleep $NGINXUPGRADESLEEP

NGINXPSCHECK=`ps --no-heading -C nginx`

if [ ! -z "$NGINXPSCHECK" ]; then
echo ""
echo "nginx seems to be still running, trying to stop it again..."
echo ""
/etc/init.d/nginx stop
sleep $NGINXUPGRADESLEEP
fi

    make install

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, Nginx wasn't installed properly\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: Nginx was installed properly\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

    /etc/init.d/nginx start

funct_showtempfile
	cleanup_msg

CBODYCHECK=`grep 'client_body_in_file_only on' /usr/local/nginx/conf/nginx.conf`
if [ $CBODYCHECK ]; then
sed -i 's/client_body_in_file_only on/client_body_in_file_only off/g' /usr/local/nginx/conf/nginx.conf
fi

    echo "*************************************************"
    cecho "* nginx updated" $boldgreen
    echo "*************************************************"

	fi

# error check
################

echo " "

if [[ "$ENABLE_MENU" != [yY] ]]; then

ASK "Do would you like to run script cleanup (Highly recommended) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    rm -rf /svr-setup
    echo "Temporary files/folders removed"
fi

ASK "Do you want to delete this script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Deleting Centmin script... " $boldgreen
    echo "*************************************************"
    echo "Removing..."

rm -f $0

    echo "*************************************************"
    cecho "* Centmin script deleted" $boldgreen
    echo "*************************************************"
fi

fi

}

function funct_phpupgrade {

    if [ ${MACHINE_TYPE} == 'x86_64' ];
    then
        ARCH='x86_64'
    else
        ARCH='i386'
    fi

# Set LIBDIR
if [ ${ARCH} == 'x86_64' ];
then
    LIBDIR='lib64'
else
    LIBDIR='lib'
fi

echo " "
ASK "PHP Upgrade - Would you like to continue? [y/n] "   
if [[ "$key" = [nN] ]];
then
    exit 0
fi

DIR_TMP="/svr-setup"
if [ ! -d "$DIR_TMP" ]; then
mkdir /svr-setup
fi

funct_mktempfile

echo -n "Install which version of PHP? (version i.e. 5.3.11): "
read phpver

    echo "*************************************************"
    cecho "* Upgrading PHP" $boldgreen
    echo "*************************************************"

funct_centos6check

    export PHP_AUTOCONF=/usr/bin/autoconf-2.13
    export PHP_AUTOHEADER=/usr/bin/autoheader-2.13

    cd $DIR_TMP

    # IMPORTANT Erase any PHP installations first, otherwise conflicts may arise
    yum -y erase php*

if [[ "$CENTOSVER" = '6.0' || "$CENTOSVER" = '6.1' || "$CENTOSVER" = '6.2' ]]; then
DOWNLOADAPP='axel -a'
WGETRETRY=''
AXELPHPTARGZ="-o php-${PHP_VERSION}.tar.gz"
AXELPHPUPGRADETARGZ="-o php-${phpver}.tar.gz"
else
DOWNLOADAPP='wget -c'
WGETRETRY='--tries=3'
AXELPHPTARGZ=''
AXELPHPUPGRADETARGZ=''
fi

    if [ -s php-${phpver}.tar.gz ]; then
        cecho "php ${phpver} Archive found, skipping download..." $boldgreen
    else
        $DOWNLOADAPP ${PHPUPGRADE_MIRRORURL}/get/php-${phpver}.tar.gz/from/this/mirror $AXELPHPUPGRADETARGZ $WGETRETRY
    fi

    tar xzvf php-${phpver}.tar.gz

    cd php-${phpver}

##############################################
# begin update php.ini

echo ""
echo "*************************************************"
cecho "* Updating php.ini... " $boldgreen
echo "*************************************************"
echo "old php.ini will be saved at /usr/local/lib/php.ini-oldversion_$DT"
echo "if you have modified your old php.ini i.e. installed and loaded"
echo "APC, Xcache, Memcache or Suhosin - please re-install them after php upgrade"
echo "..."

    cp -f /usr/local/lib/php.ini /usr/local/lib/php.ini-oldversion_$DT
    cp -f php.ini-production /usr/local/lib/php.ini
    chmod 644 /usr/local/lib/php.ini

phpsededit

PHPDIFF=`diff /usr/local/lib/php.ini /usr/local/lib/php.ini-oldversion_$DT`
echo ""
if [ ! -z "$PHPDIFF" ]; then
echo "checking updated php.ini compared to old /usr/local/lib/php.ini-oldversion_$DT"
echo "please note the following differences: "
echo "if APC, Xcache, Memcache, Suhosin or FFMPEG Extensions are listed please re-install them"
echo ""
echo "--------------------------------------------------------------------------------------------"
diff /usr/local/lib/php.ini /usr/local/lib/php.ini-oldversion_$DT
echo "--------------------------------------------------------------------------------------------"
echo ""
    echo "*************************************************"
echo "Automatically continuing upgrade in 30 seconds..."
    echo "*************************************************"
sleep 60
echo ""
fi # PHPDIFF

# end update php.ini
##############################################

    make clean

    ./buildconf --force
    
    if [ ! -d fpm-build ]; then
    mkdir fpm-build 
    fi
    
    cd fpm-build

    make clean

    #mkdir -p /usr/${LIBDIR}/mysql
    #ln -s /usr/${LIBDIR}/libmysqlclient.so /usr/${LIBDIR}/mysql/libmysqlclient.so

funct_phpconfigure

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, PHP configure failed ($SCRIPT_VERSION)\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: PHP configure ok\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

    /etc/init.d/php-fpm restart

funct_showtempfile
	cleanup_msg

	fi

# error check
################

    make${MAKETHREADS}

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, PHP make failed ($SCRIPT_VERSION)\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: PHP make ok\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

    /etc/init.d/php-fpm restart

funct_showtempfile
	cleanup_msg

	fi

# error check
################

    make install

################
# error check

	ERR=$?
	if [ $ERR != 0 ]; then
	NOTIFY_MESSAGE="\n`date`\nError: $ERR, PHP wasn't installed properly ($SCRIPT_VERSION)\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

funct_showtempfile
	cleanup_msg

	exit
	
	else

	NOTIFY_MESSAGE="\n`date`\nSuccess: PHP was installed properly\n"
	echo -e "$NOTIFY_MESSAGE" >> "$TMP_MSGFILE"

echo
echo

read -p "Do you want to update to latest php-fpm.conf ? It will overwrite your existing php-fpm.conf [y/n]: " overwritephpfpmconf

if [[ "$overwritephpfpmconf" = [yY] ]]; then

read -p "Does this server have less than <=2048MB of memory installed ? [y/n]: " lessphpmem

echo
echo "Backing up existing php-fpm.conf at /usr/local/etc/php-fpm.conf-oldversion_$DT"
echo "If you have made an custom changes to /usr/local/etc/php-fpm.conf, you will find"
echo "they still exist in backup at /usr/local/etc/php-fpm.conf-oldversion_$DT"

    cp -f /usr/local/etc/php-fpm.conf /usr/local/etc/php-fpm.conf-oldversion_$DT
    ls -lhrt /usr/local/etc/ | grep php-fpm.conf

sleep 60

echo 

if [[ "$lessphpmem" = [yY] ]]; then

echo $lessphpmem

echo -e "\nCopying php-fpm-min.conf /usr/local/etc/php-fpm.conf\n"
    cp $CUR_DIR/config/php-fpm/php-fpm-min.conf /usr/local/etc/php-fpm.conf

else

echo $lessphpmem

echo -e "\nCopying php-fpm.conf /usr/local/etc/php-fpm.conf\n"
    cp $CUR_DIR/config/php-fpm/php-fpm.conf /usr/local/etc/php-fpm.conf

fi # lessphpmem

fi # overwritephpfpmconf

    /etc/init.d/php-fpm restart

funct_showtempfile
	cleanup_msg

if [ -f /usr/local/nginx/html/phpi.php ]; then
# Randomize phpi.php filename
NPHP=$RANDOM
mv /usr/local/nginx/html/phpi.php /usr/local/nginx/html/${NPHP}_phpi.php
chown nginx:nginx /usr/local/nginx/html/${NPHP}_phpi.php
fi

    echo "*************************************************"
    cecho "* PHP upgraded" $boldgreen
    echo "*************************************************"

	fi

# error check
################


if [[ "$ENABLE_MENU" != [yY] ]]; then

ASK "Do would you like to run script cleanup (Highly recommended) ? [y/n] "
if [[ "$key" = [yY] ]];
then
    rm -rf /svr-setup
    echo "Temporary files/folders removed"
fi

ASK "Do you want to delete this script ? [y/n] "
if [[ "$key" = [yY] ]];
then
    echo "*************************************************"
    cecho "* Deleting Centmin script... " $boldgreen
    echo "*************************************************"
    echo "Removing..."

rm -f $0

    echo "*************************************************"
    cecho "* Centmin script deleted" $boldgreen
    echo "*************************************************"
fi

fi

}

function funct_memcachedreinstall {

    echo "*************************************************"
    cecho "* Installing memcached" $boldgreen
    echo "*************************************************"
    echo "Downloading memcached..."
    cd /svr-setup

if [ -s libevent-${LIBEVENT_VERSION}-stable.tar.gz ]; then
  cecho "libevent-${LIBEVENT_VERSION}-stable.tar.gz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: libevent-${LIBEVENT_VERSION}-stable.tar.gz not found!!!download now......"
        wget -c --no-check-certificate https://github.com/downloads/libevent/libevent/libevent-${LIBEVENT_VERSION}-stable.tar.gz --tries=3
fi

if [ -s memcached-${MEMCACHED_VERSION}.tar.gz ]; then
  cecho "memcached-${MEMCACHED_VERSION}.tar.gz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: memcached-${MEMCACHED_VERSION}.tar.gz not found!!!download now......"
        $DOWNLOADAPP http://memcached.googlecode.com/files/memcached-${MEMCACHED_VERSION}.tar.gz $WGETRETRY
fi

if [ -s memcache-${MEMCACHE_VERSION}.tgz ]; then
  cecho "memcache-${MEMCACHE_VERSION}.tgz Archive found, skipping download..." $boldgreen
  else
  cecho "Error: memcache-${MEMCACHE_VERSION}.tgz not found!!!download now......"
        $DOWNLOADAPP http://pecl.php.net/get/memcache-${MEMCACHE_VERSION}.tgz $WGETRETRY
fi

    cecho "Compiling libevent..." $boldgreen

# Set LIBDIR
if [ ${ARCH} == 'x86_64' ];
then
    LIBDIR='lib64'
else
    LIBDIR='lib'
fi

echo $ARCH
echo $LIBDIR

cd /svr-setup
tar xfz libevent-${LIBEVENT_VERSION}-stable.tar.gz
cd libevent-${LIBEVENT_VERSION}-stable
./configure --prefix=/usr/${LIBDIR}
make clean
make && make install

echo "/usr/${LIBDIR}/lib/" > /etc/ld.so.conf.d/libevent-i386.conf
ldconfig

    cecho "Compiling memcached..." $boldgreen

cd /svr-setup
tar xzf memcached-${MEMCACHED_VERSION}.tar.gz
cd memcached-${MEMCACHED_VERSION}
./configure --with-libevent=/usr/${LIBDIR}
make clean
make && make install
cp -f /svr-setup/memcached-${MEMCACHED_VERSION}/scripts/memcached-tool /usr/local/bin

    cecho "Compiled memcached..." $boldgreen

killall memcached
sleep 5
service memcached stop
service memcached start

    cecho "Compiling PHP memcache extension..." $boldgreen

cd /svr-setup
tar -xvf memcache-${MEMCACHE_VERSION}.tgz
cd memcache-${MEMCACHE_VERSION}
/usr/local/bin/phpize
./configure --enable-memcache --with-php-config=/usr/local/bin/php-config
make clean
make && make install

#######################################################
# check to see if memcache.so already loaded in php.ini

MEMCACHESOCHECK=`grep 'memcache.so' /usr/local/lib/php.ini`
PHPEXTDIR=`cat /usr/local/bin/php-config | awk '/^extension_dir/ {extdir=$1} END {gsub(/\047|extension_dir|=|)/,"",extdir); print extdir}'`

if [[ -z $MEMCACHESOCHECK ]]; then

echo "" >> /usr/local/lib/php.ini
echo "extension=${PHPEXTDIR}/memcache.so" >> /usr/local/lib/php.ini

else

echo ""
echo "memcache.so already loaded in /usr/local/lib/php.ini"
echo "$MEMCACHESOCHECK"
echo ""

fi # memcache.so check

/etc/init.d/php-fpm restart

}

function funct_timestamp {


echo "..."
echo "Time:"   
echo "********************************"
echo "================================"
date
echo "================================"
echo "********************************"

}

function funct_installiopingcentmin {

echo ""
	cecho "--------------------------------------------------------" $boldyellow
echo "Where do you want the iopingcentmin.sh stored ? Enter path to download directory (i.e. /root or /usr/local/src): "
read iopingdownloadpath

    cd $iopingdownloadpath

if [ -s iopingcentmin.sh ]; then

	echo ""
	echo "iopingcentmin.sh [found]"

	echo ""
	echo "Do you want to download latest iopincentmin.sh version ? [y/n]: "
	read iopingdownloadupdate

	if [[ $iopingdownloadupdate = [yY] ]]; then

	rm -rf iopingcentmin.sh
	$DOWNLOADAPP http://vbtechsupport.com/centminmenu/iopingcentmin/iopingcentmin.sh $WGETRETRY

	echo ""
	cecho "--------------------------------------------------------" $boldyellow
	echo "script installed at $iopingdownloadpath/iopingcentmin.sh"
	echo "to manually run iopingcentmin.sh type:"
	echo "bash $iopingdownloadpath/iopingcentmin.sh"
	cecho "--------------------------------------------------------" $boldyellow
	echo ""

	exit

	else

	exit

	fi

  else
  echo "Error: iopingcentmin.sh not found!!!download now......"
  $DOWNLOADAPP http://vbtechsupport.com/centminmenu/iopingcentmin/iopingcentmin.sh $WGETRETRY

fi

chmod +x iopingcentmin.sh

	echo ""
	cecho "--------------------------------------------------------" $boldyellow
	echo "script installed at $iopingdownloadpath/iopingcentmin.sh"
	echo "to manually run iopingcentmin.sh type:"
	echo "bash $iopingdownloadpath/iopingcentmin.sh"
	cecho "--------------------------------------------------------" $boldyellow
	echo ""


}

function funct_selinux {

SELINUXCONFIGFILE='/etc/selinux/config'
SELINUXCHECK=`grep '^SELINUX=' /etc/selinux/config | cut -d '=' -f2`

if [[ $SELINUXCHECK == 'enforcing' ]]; then

	echo ""
cecho "---------------------------------------------" $boldyellow
	echo "Checking SELinux status...."
	echo "SELinux enabled"
	echo ""
	read -p "Do you want to disable SELinux ? [y/n]: " disableselinux
cecho "---------------------------------------------" $boldyellow
	echo ""

	if [[ $disableselinux == [yY] ]]; then

	echo ""
cecho "---------------------------------------------" $boldyellow
	echo "Disabling SELinux..."

	sed -i 's/SELINUX=enforcing/SELINUX=disabled/g' $SELINUXCONFIGFILE
	setenforce 0

	echo ""
cecho "---------------------------------------------" $boldyellow
	echo "checking $SELINUXCONFIGFILE"

	cat $SELINUXCONFIGFILE | grep '^SELINUX='

cecho "---------------------------------------------" $boldyellow
	echo ""

	exit

	else

	exit

	fi

else

	echo ""
cecho "---------------------------------------------" $boldyellow
	echo "checking $SELINUXCONFIGFILE"
	echo "SELinux already disabled"
	echo "SELINUX=$SELINUXCHECK"
cecho "---------------------------------------------" $boldyellow
	echo ""

	exit

fi

}

function funct_showtempfile {

    echo "*************************************************"
	cat "$TMP_MSGFILE"
    echo "*************************************************"

}

function funct_mktempfile {

if [[ ! -d "$DIR_TMP"/msglogs ]]; then
cd $DIR_TMP
mkdir msglogs
chmod 1777 $DIR_TMP/msglogs
fi

TMP_MSGFILE="$DIR_TMP/msglogs/$RANDOM.msg"

}

function cleanup_msg {
	rm -f "$TMP_MSGFILE"
	#exit 1
}

# http://linuxcommand.org/wss0160.php
trap clean_msg SIGHUP SIGINT SIGTERM

################################
# http://www.hardened-php.net/suhosin/
suhosinsetup() {

PHPVERCHECK=`cat /usr/local/bin/php-config | awk '/^version/ {phpver=$1} END {gsub(/"|version|=|)/,"",phpver); print phpver}' | awk -F "." '{print $1"."$2}'`

if [ "$PHPVERCHECK" != '5.4' ]; then

cd /svr-setup

if [ -s suhosin-${SUHOSINVER}.tgz ]; then
  echo "suhosin-${SUHOSINVER}.tgz [found]"
  else
  echo "Error: suhosin-${SUHOSINVER}.tgz not found!!!download now......"
  wget -c http://download.suhosin.org/suhosin-${SUHOSINVER}.tgz --tries=3
fi

tar xvzf suhosin-${SUHOSINVER}.tgz
cd suhosin-${SUHOSINVER}
make clean
phpize
./configure
make
make install

SUHOSINCHECK=`grep 'extension=suhosin.so' /usr/local/lib/php.ini `
if [ -z "$SUHOSINCHECK" ]; then
echo "" >> /usr/local/lib/php.ini
echo "extension=suhosin.so" >> /usr/local/lib/php.ini

cat >>/usr/local/lib/php.ini<<EOF
suhosin.simulation = 0
suhosin.cookie.encrypt = 0
suhosin.executor.disable_eval = 0
suhosin.get.max_value_length = 2048
suhosin.get.max_vars = 1000
suhosin.memory_limit = 0
suhosin.post.max_value_length = 1000000
suhosin.post.max_vars = 1000
suhosin.request.max_value_length = 1000000
suhosin.request.max_vars = 1000
suhosin.upload.disallow_binary = 0
suhosin.upload.disallow_elf = 1
suhosin.upload.max_uploads = 25
suhosin.upload.remove_binary = 0
EOF

fi

if [ ! -z "$SUHOSINCHECK" ]; then
    echo "sed -i 's/;extension=suhosin.so/extension=suhosin.so/g' /usr/local/lib/php.ini; fpmrestart; php -v" >/usr/bin/suhosinon ; chmod 700 /usr/bin/suhosinon
    echo "sed -i 's/extension=suhosin.so/;extension=suhosin.so/g' /usr/local/lib/php.ini; fpmrestart; php -v" >/usr/bin/suhosinoff ; chmod 700 /usr/bin/suhosinoff
fi

service php-fpm restart

php -v

else 

echo ""
echo ""
echo "$PHPVERCHECK not compatible with Suhosin PHP extension"
echo "install aborted"
echo ""
echo ""

fi # PHPVERCHECK

} # suhosininstall

# end functions
#####################################################################
#####################################################################


#########################################################

if [[ "$ENABLE_MENU" = [yY] ]]; then

while :
do
	# clear
        # display menu
	cecho "--------------------------------------------------------" $boldyellow
	cecho "Centmin $SCRIPT_VERSION - $SCRIPT_URL" $boldgreen
	#cecho "Menu/Mods Author: $SCRIPT_MODIFICATION_AUTHOR" $boldgreen
	#cecho "Centmin Original Author: $SCRIPT_AUTHOR" $boldgreen
	cecho "--------------------------------------------------------" $boldyellow
	cecho "                   Centmin Menu                   " $boldgreen
	cecho "--------------------------------------------------------" $boldyellow
	cecho "1).  Centmin Install" $boldgreen
	cecho "2).  Add Nginx vhost domain" $boldgreen
	cecho "3).  NSD setup domain name DNS" $boldgreen
	cecho "4).  Nginx Upgrade" $boldgreen
	cecho "5).  PHP Upgrade" $boldgreen
	cecho "6).  XCache Re-install" $boldgreen
	cecho "7).  APC Cache Re-install" $boldgreen
	cecho "8).  XCache Install" $boldgreen
	cecho "9).  APC Cache Install" $boldgreen
	cecho "10). Memcached Server Re-install" $boldgreen
	cecho "11). MariaDB 5.2 Upgrade" $boldgreen
	cecho "12). Install ioping.sh vbtechsupport.com/1239/" $boldgreen
	cecho "13). SELinux disable" $boldgreen
	cecho "14). Setup Logrotate for Nginx" $boldgreen
	cecho "15). Setup Logrotate for PHP-FPM" $boldgreen
	cecho "16). Change SSHD Port Number" $boldgreen
	cecho "17). Multi-thread compression: pigz,pbzip2,lbzip2,p7zip etc" $boldgreen
	cecho "18). Suhosin PHP Extension install" $boldgreen
	cecho "19). Install FFMPEG and FFMPEG PHP Extension" $boldgreen
	cecho "20). NSD Re-install" $boldgreen
	cecho "21). Exit" $boldgreen
	cecho "--------------------------------------------------------" $boldyellow

	read -p "Enter option [ 1 - 21 ] " option
	cecho "--------------------------------------------------------" $boldyellow

#########################################################

case "$option" in
1|install)

centminlog
diskalert
{
funct_centmininstall
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_install.log

;;
2|addvhost)

centminlog
{
funct_nginxaddvhost
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_nginx_addvhost.log

;;
3|nsdsetup)

centminlog
{
funct_nsdsetup
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_nsd_setup.log

;;
4|nginxupgrade)

centminlog
diskalert
csftweaks

{
yuminstall
funct_nginxupgrade
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_nginx_upgrade.log

;;
5|phpupgrade)

centminlog
diskalert
csftweaks

{
yuminstall
funct_phpupgrade
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_php_upgrade.log

;;
6|xcachereinstall)

centminlog
{
funct_xcachereinstall
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_xcache_reinstall.log

;;
7|apcreinstall)

centminlog
{
funct_apcreinstall
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_apc_reinstall.log

;;
8|installxcache)

centminlog
{
funct_installxcache
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_xcache_install.log

;;
9|installapc)

centminlog
{
funct_installapc
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_apc_install.log

;;
10|memcachedreinstall)

centminlog
{
funct_memcachedreinstall
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_memcached_reinstall.log

;;
11|mariadbupgrade)

centminlog
{
funct_mariadbupgrade
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_mariadb_upgrade.log

;;
12|iopinginstall)

funct_installiopingcentmin

;;
13|selinux)

funct_selinux

;;
14|logrotate)

funct_logrotate

;;
15|phplogrotate)

funct_logphprotate

;;
16|sshdport)

funct_sshd

;;
17|multithreadcomp)

funct_pigzinstall
funct_pbzip2install
funct_lbzip2install
funct_lzipinstall
funct_plzipinstall
funct_p7zipinstall

;;
18|suhosininstall)
centminlog
{
suhosinsetup
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_suhosin_install.log
;;
19|ffmpeginstall)
centminlog
{
ffmpegsetup
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_ffmpeg_install.log
;;
20|nsdreinstall)
centminlog
{
nsdreinstall
} 2>&1 | tee ${CENTMINLOGDIR}/centminmod_${SCRIPT_VERSION}_${DT}_nsd_reinstall.log
;;
21|exit)

echo ""
echo "exit"
exit 0

;;

esac

done

else

case "$1" in
install)

diskalert
funct_centmininstall

;;
addvhost)

funct_nginxaddvhost

;;
nsdsetup)

funct_nsdsetup

;;
nginxupgrade)

diskalert
csftweaks
yuminstall
funct_nginxupgrade

;;
phpupgrade)

diskalert
csftweaks
yuminstall
funct_phpupgrade

;;
xcachereinstall)

funct_xcachereinstall

;;
apcreinstall)

funct_apcreinstall

;;
installxcache)

funct_installxcache

;;
installapc)

funct_installapc

;;
memcachedreinstall)

funct_memcachedreinstall

;;
mariadbupgrade)

funct_mariadbupgrade

;;
iopinginstall)

funct_installiopingcentmin

;;
selinux)

funct_selinux

;;
logrotate)

funct_logrotate

;;
phplogrotate)

funct_logphprotate

;;
sshdport)

funct_sshd

;;
multithreadcomp)

funct_pigzinstall
funct_pbzip2install
funct_lbzip2install
funct_lzipinstall
funct_plzipinstall
funct_p7zipinstall

;;
suhosininstall)
suhosinsetup
;;
ffmpeginstall)
ffmpegsetup
;;
nsdreinstall)
nsdreinstall
;;
exit)

echo ""
echo "exit"
exit 0

;;
*)

echo "$0 install"
echo "$0 addvhost"
echo "$0 nsdsetup"
echo "$0 nginxupgrade"
echo "$0 phpupgrade"
echo "$0 xcachereinstall"
echo "$0 apcreinstall"
echo "$0 installxcache"
echo "$0 installapac"
echo "$0 memcachedreinstall"
echo "$0 mariadbupgrade"
echo "$0 installioping"
echo "$0 selinux"
echo "$0 logrotate"
echo "$0 phplogrotate"
echo "$0 sshdport"
echo "$0 multithreadcomp"
echo "$0 suhosininstall"
echo "$0 ffmpeginstall"
echo "$0 nsdreinstall"

;;
esac

fi

exit 0